==> ppl_1.1.orig.tar.xz: ppl-user-java-interface-1.1-html/namespaceparma__polyhedra__library.js <==
var namespaceparma__polyhedra__library =
[
    [ "Artificial_Parameter", "classparma__polyhedra__library_1_1Artificial__Parameter.html", "classparma__polyhedra__library_1_1Artificial__Parameter" ],
    [ "Artificial_Parameter_Sequence", "classparma__polyhedra__library_1_1Artificial__Parameter__Sequence.html", "classparma__polyhedra__library_1_1Artificial__Parameter__Sequence" ],
    [ "Bounded_Integer_Type_Overflow", "enumparma__polyhedra__library_1_1Bounded__Integer__Type__Overflow.html", "enumparma__polyhedra__library_1_1Bounded__Integer__Type__Overflow" ],
    [ "Bounded_Integer_Type_Representation", "enumparma__polyhedra__library_1_1Bounded__Integer__Type__Representation.html", "enumparma__polyhedra__library_1_1Bounded__Integer__Type__Representation" ],
    [ "Bounded_Integer_Type_Width", "enumparma__polyhedra__library_1_1Bounded__Integer__Type__Width.html", "enumparma__polyhedra__library_1_1Bounded__Integer__Type__Width" ],
    [ "By_Reference< T >", "classparma__polyhedra__library_1_1By__Reference_3_01T_01_4.html", "classparma__polyhedra__library_1_1By__Reference_3_01T_01_4" ],
    [ "Coefficient", "classparma__polyhedra__library_1_1Coefficient.html", "classparma__polyhedra__library_1_1Coefficient" ],
    [ "Complexity_Class", "enumparma__polyhedra__library_1_1Complexity__Class.html", "enumparma__polyhedra__library_1_1Complexity__Class" ],
    [ "Congruence", "classparma__polyhedra__library_1_1Congruence.html", "classparma__polyhedra__library_1_1Congruence" ],
    [ "Congruence_System", "classparma__polyhedra__library_1_1Congruence__System.html", "classparma__polyhedra__library_1_1Congruence__System" ],
    [ "Constraint", "classparma__polyhedra__library_1_1Constraint.html", "classparma__polyhedra__library_1_1Constraint" ],
    [ "Constraint_System", "classparma__polyhedra__library_1_1Constraint__System.html", "classparma__polyhedra__library_1_1Constraint__System" ],
    [ "Control_Parameter_Name", "enumparma__polyhedra__library_1_1Control__Parameter__Name.html", "enumparma__polyhedra__library_1_1Control__Parameter__Name" ],
    [ "Control_Parameter_Value", "enumparma__polyhedra__library_1_1Control__Parameter__Value.html", "enumparma__polyhedra__library_1_1Control__Parameter__Value" ],
    [ "Degenerate_Element", "enumparma__polyhedra__library_1_1Degenerate__Element.html", "enumparma__polyhedra__library_1_1Degenerate__Element" ],
    [ "Domain_Error_Exception", "classparma__polyhedra__library_1_1Domain__Error__Exception.html", "classparma__polyhedra__library_1_1Domain__Error__Exception" ],
    [ "Polyhedron", "classparma__polyhedra__library_1_1Polyhedron.html", "classparma__polyhedra__library_1_1Polyhedron" ],
    [ "C_Polyhedron", "classparma__polyhedra__library_1_1C__Polyhedron.html", "classparma__polyhedra__library_1_1C__Polyhedron" ],
    [ "Pointset_Powerset_C_Polyhedron", "classparma__polyhedra__library_1_1Pointset__Powerset__C__Polyhedron.html", "classparma__polyhedra__library_1_1Pointset__Powerset__C__Polyhedron" ],
    [ "Pointset_Powerset_C_Polyhedron_Iterator", "classparma__polyhedra__library_1_1Pointset__Powerset__C__Polyhedron__Iterator.html", "classparma__polyhedra__library_1_1Pointset__Powerset__C__Polyhedron__Iterator" ],
    [ "Generator", "classparma__polyhedra__library_1_1Generator.html", "classparma__polyhedra__library_1_1Generator" ],
    [ "Generator_System", "classparma__polyhedra__library_1_1Generator__System.html", "classparma__polyhedra__library_1_1Generator__System" ],
    [ "Generator_Type", "enumparma__polyhedra__library_1_1Generator__Type.html", "enumparma__polyhedra__library_1_1Generator__Type" ],
    [ "Grid_Generator", "classparma__polyhedra__library_1_1Grid__Generator.html", "classparma__polyhedra__library_1_1Grid__Generator" ],
    [ "Grid_Generator_System", "classparma__polyhedra__library_1_1Grid__Generator__System.html", "classparma__polyhedra__library_1_1Grid__Generator__System" ],
    [ "Grid_Generator_Type", "enumparma__polyhedra__library_1_1Grid__Generator__Type.html", "enumparma__polyhedra__library_1_1Grid__Generator__Type" ],
    [ "Invalid_Argument_Exception", "classparma__polyhedra__library_1_1Invalid__Argument__Exception.html", "classparma__polyhedra__library_1_1Invalid__Argument__Exception" ],
    [ "IO", "classparma__polyhedra__library_1_1IO.html", null ],
    [ "Length_Error_Exception", "classparma__polyhedra__library_1_1Length__Error__Exception.html", "classparma__polyhedra__library_1_1Length__Error__Exception" ],
    [ "Linear_Expression", "classparma__polyhedra__library_1_1Linear__Expression.html", "classparma__polyhedra__library_1_1Linear__Expression" ],
    [ "Linear_Expression_Coefficient", "classparma__polyhedra__library_1_1Linear__Expression__Coefficient.html", "classparma__polyhedra__library_1_1Linear__Expression__Coefficient" ],
    [ "Linear_Expression_Difference", "classparma__polyhedra__library_1_1Linear__Expression__Difference.html", "classparma__polyhedra__library_1_1Linear__Expression__Difference" ],
    [ "Linear_Expression_Sum", "classparma__polyhedra__library_1_1Linear__Expression__Sum.html", "classparma__polyhedra__library_1_1Linear__Expression__Sum" ],
    [ "Linear_Expression_Times", "classparma__polyhedra__library_1_1Linear__Expression__Times.html", "classparma__polyhedra__library_1_1Linear__Expression__Times" ],
    [ "Linear_Expression_Unary_Minus", "classparma__polyhedra__library_1_1Linear__Expression__Unary__Minus.html", "classparma__polyhedra__library_1_1Linear__Expression__Unary__Minus" ],
    [ "Linear_Expression_Variable", "classparma__polyhedra__library_1_1Linear__Expression__Variable.html", "classparma__polyhedra__library_1_1Linear__Expression__Variable" ],
    [ "Logic_Error_Exception", "classparma__polyhedra__library_1_1Logic__Error__Exception.html", "classparma__polyhedra__library_1_1Logic__Error__Exception" ],
    [ "MIP_Problem", "classparma__polyhedra__library_1_1MIP__Problem.html", "classparma__polyhedra__library_1_1MIP__Problem" ],
    [ "MIP_Problem_Status", "enumparma__polyhedra__library_1_1MIP__Problem__Status.html", "enumparma__polyhedra__library_1_1MIP__Problem__Status" ],
    [ "Optimization_Mode", "enumparma__polyhedra__library_1_1Optimization__Mode.html", "enumparma__polyhedra__library_1_1Optimization__Mode" ],
    [ "Overflow_Error_Exception", "classparma__polyhedra__library_1_1Overflow__Error__Exception.html", "classparma__polyhedra__library_1_1Overflow__Error__Exception" ],
    [ "Pair< K, V >", "classparma__polyhedra__library_1_1Pair_3_01K_00_01V_01_4.html", "classparma__polyhedra__library_1_1Pair_3_01K_00_01V_01_4" ],
    [ "Parma_Polyhedra_Library", "classparma__polyhedra__library_1_1Parma__Polyhedra__Library.html", null ],
    [ "Partial_Function", "classparma__polyhedra__library_1_1Partial__Function.html", "classparma__polyhedra__library_1_1Partial__Function" ],
    [ "PIP_Decision_Node", "classparma__polyhedra__library_1_1PIP__Decision__Node.html", "classparma__polyhedra__library_1_1PIP__Decision__Node" ],
    [ "PIP_Problem", "classparma__polyhedra__library_1_1PIP__Problem.html", "classparma__polyhedra__library_1_1PIP__Problem" ],
    [ "PIP_Problem_Control_Parameter_Name", "enumparma__polyhedra__library_1_1PIP__Problem__Control__Parameter__Name.html", "enumparma__polyhedra__library_1_1PIP__Problem__Control__Parameter__Name" ],
    [ "PIP_Problem_Control_Parameter_Value", "enumparma__polyhedra__library_1_1PIP__Problem__Control__Parameter__Value.html", "enumparma__polyhedra__library_1_1PIP__Problem__Control__Parameter__Value" ],
    [ "PIP_Problem_Status", "enumparma__polyhedra__library_1_1PIP__Problem__Status.html", "enumparma__polyhedra__library_1_1PIP__Problem__Status" ],
    [ "PIP_Solution_Node", "classparma__polyhedra__library_1_1PIP__Solution__Node.html", "classparma__polyhedra__library_1_1PIP__Solution__Node" ],
    [ "PIP_Tree_Node", "classparma__polyhedra__library_1_1PIP__Tree__Node.html", "classparma__polyhedra__library_1_1PIP__Tree__Node" ],
    [ "Poly_Con_Relation", "classparma__polyhedra__library_1_1Poly__Con__Relation.html", "classparma__polyhedra__library_1_1Poly__Con__Relation" ],
    [ "Poly_Gen_Relation", "classparma__polyhedra__library_1_1Poly__Gen__Relation.html", "classparma__polyhedra__library_1_1Poly__Gen__Relation" ],
    [ "Relation_Symbol", "enumparma__polyhedra__library_1_1Relation__Symbol.html", "enumparma__polyhedra__library_1_1Relation__Symbol" ],
    [ "Timeout_Exception", "classparma__polyhedra__library_1_1Timeout__Exception.html", "classparma__polyhedra__library_1_1Timeout__Exception" ],
    [ "Variable", "classparma__polyhedra__library_1_1Variable.html", "classparma__polyhedra__library_1_1Variable" ],
    [ "Variable_Stringifier", "interfaceparma__polyhedra__library_1_1Variable__Stringifier.html", null ],
    [ "Variables_Set", "classparma__polyhedra__library_1_1Variables__Set.html", "classparma__polyhedra__library_1_1Variables__Set" ]
];

==> ppl_1.2.orig.tar.xz: ppl-user-java-interface-1.2-html/namespaceparma__polyhedra__library.js <==
var namespaceparma__polyhedra__library =
[
    [ "Artificial_Parameter", "classparma__polyhedra__library_1_1Artificial__Parameter.html", "classparma__polyhedra__library_1_1Artificial__Parameter" ],
    [ "Artificial_Parameter_Sequence", "classparma__polyhedra__library_1_1Artificial__Parameter__Sequence.html", "classparma__polyhedra__library_1_1Artificial__Parameter__Sequence" ],
    [ "Bounded_Integer_Type_Overflow", "enumparma__polyhedra__library_1_1Bounded__Integer__Type__Overflow.html", "enumparma__polyhedra__library_1_1Bounded__Integer__Type__Overflow" ],
    [ "Bounded_Integer_Type_Representation", "enumparma__polyhedra__library_1_1Bounded__Integer__Type__Representation.html", "enumparma__polyhedra__library_1_1Bounded__Integer__Type__Representation" ],
    [ "Bounded_Integer_Type_Width", "enumparma__polyhedra__library_1_1Bounded__Integer__Type__Width.html", "enumparma__polyhedra__library_1_1Bounded__Integer__Type__Width" ],
    [ "By_Reference", "classparma__polyhedra__library_1_1By__Reference.html", "classparma__polyhedra__library_1_1By__Reference" ],
    [ "C_Polyhedron", "classparma__polyhedra__library_1_1C__Polyhedron.html", "classparma__polyhedra__library_1_1C__Polyhedron" ],
    [ "Coefficient", "classparma__polyhedra__library_1_1Coefficient.html", "classparma__polyhedra__library_1_1Coefficient" ],
    [ "Complexity_Class", "enumparma__polyhedra__library_1_1Complexity__Class.html", "enumparma__polyhedra__library_1_1Complexity__Class" ],
    [ "Congruence", "classparma__polyhedra__library_1_1Congruence.html", "classparma__polyhedra__library_1_1Congruence" ],
    [ "Congruence_System", "classparma__polyhedra__library_1_1Congruence__System.html", "classparma__polyhedra__library_1_1Congruence__System" ],
    [ "Constraint", "classparma__polyhedra__library_1_1Constraint.html", "classparma__polyhedra__library_1_1Constraint" ],
    [ "Constraint_System", "classparma__polyhedra__library_1_1Constraint__System.html", "classparma__polyhedra__library_1_1Constraint__System" ],
    [ "Control_Parameter_Name", "enumparma__polyhedra__library_1_1Control__Parameter__Name.html", "enumparma__polyhedra__library_1_1Control__Parameter__Name" ],
    [ "Control_Parameter_Value", "enumparma__polyhedra__library_1_1Control__Parameter__Value.html", "enumparma__polyhedra__library_1_1Control__Parameter__Value" ],
    [ "Degenerate_Element", "enumparma__polyhedra__library_1_1Degenerate__Element.html", "enumparma__polyhedra__library_1_1Degenerate__Element" ],
    [ "Domain_Error_Exception", "classparma__polyhedra__library_1_1Domain__Error__Exception.html", "classparma__polyhedra__library_1_1Domain__Error__Exception" ],
    [ "Generator", "classparma__polyhedra__library_1_1Generator.html", "classparma__polyhedra__library_1_1Generator" ],
    [ "Generator_System", "classparma__polyhedra__library_1_1Generator__System.html", "classparma__polyhedra__library_1_1Generator__System" ],
    [ "Generator_Type", "enumparma__polyhedra__library_1_1Generator__Type.html", "enumparma__polyhedra__library_1_1Generator__Type" ],
    [ "Grid_Generator", "classparma__polyhedra__library_1_1Grid__Generator.html", "classparma__polyhedra__library_1_1Grid__Generator" ],
    [ "Grid_Generator_System", "classparma__polyhedra__library_1_1Grid__Generator__System.html", "classparma__polyhedra__library_1_1Grid__Generator__System" ],
    [ "Grid_Generator_Type", "enumparma__polyhedra__library_1_1Grid__Generator__Type.html", "enumparma__polyhedra__library_1_1Grid__Generator__Type" ],
    [ "Invalid_Argument_Exception", "classparma__polyhedra__library_1_1Invalid__Argument__Exception.html", "classparma__polyhedra__library_1_1Invalid__Argument__Exception" ],
    [ "IO", "classparma__polyhedra__library_1_1IO.html", null ],
    [ "Length_Error_Exception", "classparma__polyhedra__library_1_1Length__Error__Exception.html", "classparma__polyhedra__library_1_1Length__Error__Exception" ],
    [ "Linear_Expression", "classparma__polyhedra__library_1_1Linear__Expression.html", "classparma__polyhedra__library_1_1Linear__Expression" ],
    [ "Linear_Expression_Coefficient", "classparma__polyhedra__library_1_1Linear__Expression__Coefficient.html", "classparma__polyhedra__library_1_1Linear__Expression__Coefficient" ],
    [ "Linear_Expression_Difference", "classparma__polyhedra__library_1_1Linear__Expression__Difference.html", "classparma__polyhedra__library_1_1Linear__Expression__Difference" ],
    [ "Linear_Expression_Sum", "classparma__polyhedra__library_1_1Linear__Expression__Sum.html", "classparma__polyhedra__library_1_1Linear__Expression__Sum" ],
    [ "Linear_Expression_Times", "classparma__polyhedra__library_1_1Linear__Expression__Times.html", "classparma__polyhedra__library_1_1Linear__Expression__Times" ],
    [ "Linear_Expression_Unary_Minus", "classparma__polyhedra__library_1_1Linear__Expression__Unary__Minus.html", "classparma__polyhedra__library_1_1Linear__Expression__Unary__Minus" ],
    [ "Linear_Expression_Variable", "classparma__polyhedra__library_1_1Linear__Expression__Variable.html", "classparma__polyhedra__library_1_1Linear__Expression__Variable" ],
    [ "Logic_Error_Exception", "classparma__polyhedra__library_1_1Logic__Error__Exception.html", "classparma__polyhedra__library_1_1Logic__Error__Exception" ],
    [ "MIP_Problem", "classparma__polyhedra__library_1_1MIP__Problem.html", "classparma__polyhedra__library_1_1MIP__Problem" ],
    [ "MIP_Problem_Status", "enumparma__polyhedra__library_1_1MIP__Problem__Status.html", "enumparma__polyhedra__library_1_1MIP__Problem__Status" ],
    [ "Optimization_Mode", "enumparma__polyhedra__library_1_1Optimization__Mode.html", "enumparma__polyhedra__library_1_1Optimization__Mode" ],
    [ "Overflow_Error_Exception", "classparma__polyhedra__library_1_1Overflow__Error__Exception.html", "classparma__polyhedra__library_1_1Overflow__Error__Exception" ],
    [ "Pair", "classparma__polyhedra__library_1_1Pair.html", "classparma__polyhedra__library_1_1Pair" ],
    [ "Parma_Polyhedra_Library", "classparma__polyhedra__library_1_1Parma__Polyhedra__Library.html", null ],
    [ "Partial_Function", "classparma__polyhedra__library_1_1Partial__Function.html", "classparma__polyhedra__library_1_1Partial__Function" ],
    [ "PIP_Decision_Node", "classparma__polyhedra__library_1_1PIP__Decision__Node.html", "classparma__polyhedra__library_1_1PIP__Decision__Node" ],
    [ "PIP_Problem", "classparma__polyhedra__library_1_1PIP__Problem.html", "classparma__polyhedra__library_1_1PIP__Problem" ],
    [ "PIP_Problem_Control_Parameter_Name", "enumparma__polyhedra__library_1_1PIP__Problem__Control__Parameter__Name.html", "enumparma__polyhedra__library_1_1PIP__Problem__Control__Parameter__Name" ],
    [ "PIP_Problem_Control_Parameter_Value", "enumparma__polyhedra__library_1_1PIP__Problem__Control__Parameter__Value.html", "enumparma__polyhedra__library_1_1PIP__Problem__Control__Parameter__Value" ],
    [ "PIP_Problem_Status", "enumparma__polyhedra__library_1_1PIP__Problem__Status.html", "enumparma__polyhedra__library_1_1PIP__Problem__Status" ],
    [ "PIP_Solution_Node", "classparma__polyhedra__library_1_1PIP__Solution__Node.html", "classparma__polyhedra__library_1_1PIP__Solution__Node" ],
    [ "PIP_Tree_Node", "classparma__polyhedra__library_1_1PIP__Tree__Node.html", "classparma__polyhedra__library_1_1PIP__Tree__Node" ],
    [ "Pointset_Powerset_C_Polyhedron", "classparma__polyhedra__library_1_1Pointset__Powerset__C__Polyhedron.html", "classparma__polyhedra__library_1_1Pointset__Powerset__C__Polyhedron" ],
    [ "Pointset_Powerset_C_Polyhedron_Iterator", "classparma__polyhedra__library_1_1Pointset__Powerset__C__Polyhedron__Iterator.html", "classparma__polyhedra__library_1_1Pointset__Powerset__C__Polyhedron__Iterator" ],
    [ "Poly_Con_Relation", "classparma__polyhedra__library_1_1Poly__Con__Relation.html", "classparma__polyhedra__library_1_1Poly__Con__Relation" ],
    [ "Poly_Gen_Relation", "classparma__polyhedra__library_1_1Poly__Gen__Relation.html", "classparma__polyhedra__library_1_1Poly__Gen__Relation" ],
    [ "Polyhedron", "classparma__polyhedra__library_1_1Polyhedron.html", "classparma__polyhedra__library_1_1Polyhedron" ],
    [ "Relation_Symbol", "enumparma__polyhedra__library_1_1Relation__Symbol.html", "enumparma__polyhedra__library_1_1Relation__Symbol" ],
    [ "Timeout_Exception", "classparma__polyhedra__library_1_1Timeout__Exception.html", "classparma__polyhedra__library_1_1Timeout__Exception" ],
    [ "Variable", "classparma__polyhedra__library_1_1Variable.html", "classparma__polyhedra__library_1_1Variable" ],
    [ "Variable_Stringifier", "interfaceparma__polyhedra__library_1_1Variable__Stringifier.html", null ],
    [ "Variables_Set", "classparma__polyhedra__library_1_1Variables__Set.html", "classparma__polyhedra__library_1_1Variables__Set" ]
];
